==> estateplat-common-1.1.0-20160803.085537-138-sources.jar: cn/gtmap/estateplat/model/exchange/transition/QzNydsyq.java <==
package cn.gtmap.estateplat.model.exchange.transition;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.io.Serializable;
import java.util.Date;

/**
 * Created with IntelliJ IDEA.
 * 农用地使用权
 * User: lj
 * Date: 15-11-19
 * Time: 下午2:22
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "qz_nydsyq")
@XmlAccessorType(XmlAccessType.FIELD)
public class QzNydsyq implements Serializable {
    @Id
    //权利编号
    @XmlElement(name = "qlbh")
    private String qlbh;
    //不动产单元编号
    @XmlElement(name = "bdcdybh")
    private String bdcdybh;
    //业务号
    @XmlElement(name = "ywh")
    private String ywh;
    //权利类型
    @XmlElement(name = "qllx")
    private String qllx;
    //坐落
    @XmlElement(name = "zl")
    private String zl;
    //发包方代码
    @XmlElement(name = "fbfdm")
    private String fbfdm;
    //发包方名称
    @XmlElement(name = "fbfmc")
    private String fbfmc;
    //承包（使用权）面积
    @XmlElement(name = "cbmj")
    private Double cbmj;
    //承包(使用)起始时间
    @XmlElement(name = "cbqssj")
    private Date cbqssj;
    //承包(使用)结束时间
    @XmlElement(name = "cbjssj")
    private Date cbjssj;
    //土地所有权性质
    @XmlElement(name = "tdsyqxz")
    private String tdsyqxz;
    //水域滩涂类型
    @XmlElement(name = "syttlx")
    private String syttlx;
    //养殖业方式
    @XmlElement(name = "yzyfs")
    private String yzyfs;
    //草原质量
    @XmlElement(name = "cyzl")
    private String cyzl;
    //适宜载畜量
    @XmlElement(name = "syzcl")
    private Integer syzcl;
    //备注
    @XmlElement(name = "bz")
    private String bz;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次业务号
    private String yywh;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次产权证号
    private String ycqzh;

    public String getYywh() {
        return yywh;
    }

    public void setYywh(String yywh) {
        this.yywh = yywh;
    }

    public String getQlbh() {
        return qlbh;
    }

    public void setQlbh(String qlbh) {
        this.qlbh = qlbh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getFbfdm() {
        return fbfdm;
    }

    public void setFbfdm(String fbfdm) {
        this.fbfdm = fbfdm;
    }

    public String getFbfmc() {
        return fbfmc;
    }

    public void setFbfmc(String fbfmc) {
        this.fbfmc = fbfmc;
    }

    public Double getCbmj() {
        return cbmj;
    }

    public void setCbmj(Double cbmj) {
        this.cbmj = cbmj;
    }

    public Date getCbqssj() {
        return cbqssj;
    }

    public void setCbqssj(Date cbqssj) {
        this.cbqssj = cbqssj;
    }

    public Date getCbjssj() {
        return cbjssj;
    }

    public void setCbjssj(Date cbjssj) {
        this.cbjssj = cbjssj;
    }

    public String getTdsyqxz() {
        return tdsyqxz;
    }

    public void setTdsyqxz(String tdsyqxz) {
        this.tdsyqxz = tdsyqxz;
    }

    public String getSyttlx() {
        return syttlx;
    }

    public void setSyttlx(String syttlx) {
        this.syttlx = syttlx;
    }

    public String getYzyfs() {
        return yzyfs;
    }

    public void setYzyfs(String yzyfs) {
        this.yzyfs = yzyfs;
    }

    public String getCyzl() {
        return cyzl;
    }

    public void setCyzl(String cyzl) {
        this.cyzl = cyzl;
    }

    public Integer getSyzcl() {
        return syzcl;
    }

    public void setSyzcl(Integer syzcl) {
        this.syzcl = syzcl;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getYcqzh() {
        return ycqzh;
    }

    public void setYcqzh(String ycqzh) {
        this.ycqzh = ycqzh;
    }
}

==> estateplat-common-1.2.3-20180710.105517-146-sources.jar: cn/gtmap/estateplat/model/exchange/transition/QzNydsyq.java <==
package cn.gtmap.estateplat.model.exchange.transition;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.io.Serializable;
import java.util.Date;

/**
 * Created with IntelliJ IDEA.
 * 农用地使用权
 * User: lj
 * Date: 15-11-19
 * Time: 下午2:22
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "qz_nydsyq")
@XmlAccessorType(XmlAccessType.FIELD)
public class QzNydsyq implements Serializable {
    @Id
    //权利编号
    @XmlElement(name = "qlbh")
    private String qlbh;
    //不动产单元编号
    @XmlElement(name = "bdcdybh")
    private String bdcdybh;
    //业务号
    @XmlElement(name = "ywh")
    private String ywh;
    //权利类型
    @XmlElement(name = "qllx")
    private String qllx;
    //坐落
    @XmlElement(name = "zl")
    private String zl;
    //发包方代码
    @XmlElement(name = "fbfdm")
    private String fbfdm;
    //发包方名称
    @XmlElement(name = "fbfmc")
    private String fbfmc;
    //承包（使用权）面积
    @XmlElement(name = "cbmj")
    private Double cbmj;
    //承包(使用)起始时间
    @XmlElement(name = "cbqssj")
    private Date cbqssj;
    //承包(使用)结束时间
    @XmlElement(name = "cbjssj")
    private Date cbjssj;
    //土地所有权性质
    @XmlElement(name = "tdsyqxz")
    private String tdsyqxz;
    //水域滩涂类型
    @XmlElement(name = "syttlx")
    private String syttlx;
    //养殖业方式
    @XmlElement(name = "yzyfs")
    private String yzyfs;
    //草原质量
    @XmlElement(name = "cyzl")
    private String cyzl;
    //适宜载畜量
    @XmlElement(name = "syzcl")
    private Integer syzcl;
    //备注
    @XmlElement(name = "bz")
    private String bz;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次业务号
    private String yywh;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次产权证号
    private String ycqzh;

    //登簿人
    @XmlElement(name = "dbr")
    private String dbr;

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getYywh() {
        return yywh;
    }

    public void setYywh(String yywh) {
        this.yywh = yywh;
    }

    public String getQlbh() {
        return qlbh;
    }

    public void setQlbh(String qlbh) {
        this.qlbh = qlbh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getFbfdm() {
        return fbfdm;
    }

    public void setFbfdm(String fbfdm) {
        this.fbfdm = fbfdm;
    }

    public String getFbfmc() {
        return fbfmc;
    }

    public void setFbfmc(String fbfmc) {
        this.fbfmc = fbfmc;
    }

    public Double getCbmj() {
        return cbmj;
    }

    public void setCbmj(Double cbmj) {
        this.cbmj = cbmj;
    }

    public Date getCbqssj() {
        return cbqssj;
    }

    public void setCbqssj(Date cbqssj) {
        this.cbqssj = cbqssj;
    }

    public Date getCbjssj() {
        return cbjssj;
    }

    public void setCbjssj(Date cbjssj) {
        this.cbjssj = cbjssj;
    }

    public String getTdsyqxz() {
        return tdsyqxz;
    }

    public void setTdsyqxz(String tdsyqxz) {
        this.tdsyqxz = tdsyqxz;
    }

    public String getSyttlx() {
        return syttlx;
    }

    public void setSyttlx(String syttlx) {
        this.syttlx = syttlx;
    }

    public String getYzyfs() {
        return yzyfs;
    }

    public void setYzyfs(String yzyfs) {
        this.yzyfs = yzyfs;
    }

    public String getCyzl() {
        return cyzl;
    }

    public void setCyzl(String cyzl) {
        this.cyzl = cyzl;
    }

    public Integer getSyzcl() {
        return syzcl;
    }

    public void setSyzcl(Integer syzcl) {
        this.syzcl = syzcl;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getYcqzh() {
        return ycqzh;
    }

    public void setYcqzh(String ycqzh) {
        this.ycqzh = ycqzh;
    }
}
